 function [EDOS] = Reactor(t,cond,P,Ru,To,T)

FT    = sum(cond(1:5));
Fc(1) = cond(1);
Fc(2) = cond(2);
Fc(3) = cond(3);
Fc(4) = cond(4);
Fc(5) = cond(5);
T     = cond(6);

%% Constantes termodinamicas 
T0=298.15; %K
% deltas de H y S, polinomio para el calculo de Cp
%          HF         SF       A             B             C            D            E
%       [kJ/mol]  [kJ/mol]
ctes=[  -74.5      -0.0805   3.4942e+01  -3.9960e-02  1.9184e-04  -1.5300e-07  3.9321e-11;     % CH4  
        -241.835   -0.0443   3.3933e+01  -8.4186e-03  2.9906e-05  -1.7825e-08  3.6934e-12;     % H20 
        -110.53     0.0893   2.9556e+01  -6.5800e-03  2.0130e-05  -1.2230e-08  2.2617e-12;     % CO
        -393.51     0.0029   2.7437e+01   4.2320e-02  -1.9555e-05  3.9970e-09  -2.9872e-13;    % CO2
         0          0        2.5399e+01   2.0178e-02  -3.8549e-05  3.1880e-08  -8.7585e-12; ]'; % H2
        
% deltas de entalpia de cada reaccion [Kj/mol] 
% Reaccion 1
% coeficientes estequiometricos
CEQ1=[-1;-1;1;0;3];
C_1=ctes*CEQ1;
DCP1= @(x) C_1(3) + C_1(4).*x+ C_1(5).*x.^2 + C_1(6).*x.^3 + C_1(7).*x.^4;
DHRXN1= C_1(1) + (integral(DCP1,T0,T)/1000);

%----------------------------------------
% Reaccion 2
% coeficientes estequiometricos
CEQ2=[-1;-2;0;1;4];
C_2=ctes*CEQ2;
DCP2= @(x) C_2(3) + C_2(4).*x+ C_2(5).*x.^2 + C_2(6).*x.^3 + C_2(7).*x.^4;
DHRXN2=C_2(1)+ (integral(DCP2,T0,T)/1000);

%----------------------------------------
% Reaccion 3
% coeficientes estequiometricos
CEQ3=[0;-1;-1;1;1];
C_3=ctes*CEQ3;
DCP3= @(x) C_2(3) + C_2(4).*x+ C_2(5).*x.^2 + C_2(6).*x.^3 + C_2(7).*x.^4;
DHRXN3=C_2(1)+ (integral(DCP3,T0,T)/1000);


%% Calores Especficos / Funciones polinmicas de la Temperatura

polyCp1=@(x) ctes(3,1)+ctes(4,1).*x+ctes(5,1).*x.^2+ctes(6,1).*x.^3+ctes(7,1).*x.^4;% [kJ/mol-K]
                                              
polyCp2=@(x) ctes(3,2)+ctes(4,2).*x+ctes(5,2).*x.^2+ctes(6,2).*x.^3+ctes(7,2).*x.^4;% [kJ/mol-K]
                                              
polyCp3=@(x) ctes(3,2)+ctes(4,3).*x+ctes(5,3).*x.^2+ctes(6,3).*x.^3+ctes(7,3).*x.^4; % [kJ/mol-K]

polyCp4=@(x) ctes(3,4)+ctes(4,4).*x+ctes(5,4).*x.^2+ctes(6,4).*x.^3+ctes(7,4).*x.^4; % [kJ/mol-K]

polyCp5=@(x) ctes(3,5)+ctes(4,5).*x+ctes(5,5).*x.^2+ctes(6,5).*x.^3+ctes(7,5).*x.^4; % [kJ/mol-K]

%% Evaluacin de los calores especficos

CP(1)=(integral(polyCp1,To,T)/1000); % [kJ/mol]
CP(2)=(integral(polyCp2,T0,T)/1000); % [kJ/mol]   
CP(3)=(integral(polyCp3,To,T)/1000);  % [kJ/mol]
CP(4)=(integral(polyCp4,To,T)/1000); % [kJ/mol]
CP(5)=(integral(polyCp5,To,T)/1000);  % [kJ/mol]

%% Constantes especfica de velocidad de Reaccin
ko=[1.17e+15 2.83e+14 5.43e+5].*3600; % [mol/kgcat-s]
EA=[24.1 243.9 6.713];          % [kJ/mol]

k(1)=ko(1)*exp(-EA(1)/(Ru*T));
k(2)=ko(2)*exp(-EA(2)/(Ru*T));
k(3)=ko(3)*exp(-EA(3)/(Ru*T));
 
%% Constantes especficas de adsorcin 

KoAD=[6.65e-4 1.77e+5 8.23e-5 6.12e-9].*3600; % [mol/kgcat-s]
DHAD=[-38.28 88.68 -82.9 -70.65];       % [kJ/mol]

KAD(1)=KoAD(1)*exp(-DHAD(1)/(Ru*T)); % CH4
KAD(2)=KoAD(2)*exp(-DHAD(2)/(Ru*T)); % H20
KAD(3)=KoAD(3)*exp(-DHAD(3)/(Ru*T)); % CO
KAD(4)=KoAD(4)*exp(-DHAD(4)/(Ru*T)); % H2

%% Constante termodinmico de equilibrio 

K(1)=exp((-26830/T) + 30.114); % [bar^2]
K(2)=exp((4400/T) - 4.036);    % [-]
K(3)=K(1)*K(2);                % [bar^2]

 
%% Presiones parciales de cada componente 

Pp(1)=(Fc(1)/FT)*P; % [bar]
Pp(2)=(Fc(2)/FT)*P; % [bar]
Pp(3)=(Fc(3)/FT)*P; % [bar]
Pp(4)=(Fc(4)/FT)*P; % [bar]
Pp(5)=(Fc(5)/FT)*P; % [bar]

%% Leyes de velocidad 

Q = 1 + KAD(1)*Pp(1) + KAD(3)*Pp(3) +KAD(4)*Pp(5) + (KAD(2)*(Pp(2)/Pp(5))); % Termino que agrupa los efectos de difusin sobre el catalizador 

R(1)=(k(1)/Pp(5)^2.5)*((Pp(1)*Pp(2))-((Pp(5)*Pp(3))/K(1)))*(1/Q^2);     % [mol/kgcat-s-bar^2.5]

R(2)=(k(2)/Pp(5)^3.5)*((Pp(1)*Pp(2)^2)-((Pp(5)^4*Pp(4))/K(3)))*(1/Q^2); % [mol/kgcat-s-bar^3.5]
 
R(3)=(k(3)/Pp(5))*((Pp(3)*Pp(2))-((Pp(5)*Pp(4))/K(2)))*(1/Q^2);         % [[mol/kgcat-s-bar]

nu(1)=0.07; % Efectividad heterognea de la Rxn 1

nu(2)=0.06; % Efectividad heterognea de la Rxn 2

nu(3)=0.7;  % Efectividad heterognea de la Rxn 3

r(1)= -nu(1)*R(1) - nu(2)*R(2); 

r(2)= -nu(2)*R(1) - 2*nu(2)*R(2) - nu(3)*R(3); 

r(3)=  nu(1)*R(1) - nu(3)*R(3); 

r(4)=  nu(2)*R(2) + nu(3)*R(3);

r(5)=  nu(1)*R(1) + 4*nu(2)*R(2) + nu(3)*R(3);

%% Balance de Materia

dFc(1)= r(1);

dFc(2)= r(2);

dFc(3)= r(3);

dFc(4)= r(4);

dFc(5)= r(5);

%% Balance de Energa 

% ADIABTICO
dT=( (r(1)*-DHRXN1) + (r(2)*-DHRXN2) + (r(3)*-DHRXN3) )/( (Fc(1)*CP(1)) + (Fc(2)*CP(2)) + (Fc(3)*CP(3)) + (Fc(4)*CP(4)) + (Fc(5)*CP(5)) ) ;

%% SISTEMA INDEPENDIENTE DE EDOS

EDOS=[dFc(1) dFc(2) dFc(3) dFc(4) dFc(5) dT]';



 end
